summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPhilipp Wiesemann <philipp.wiesemann@arcor.de>2013-05-05 15:50:21 +0200
committerPhilipp Wiesemann <philipp.wiesemann@arcor.de>2013-05-05 15:50:21 +0200
commit1773e82524882b7b2207fc08baed1d2d4255d294 (patch)
treedf0fd933f4da930fa642d61a528551f30fa33090
parentbf4b77bbce34c2056321cf072be9f677b48b23a8 (diff)
Changed signature of method recently added in Java file.
-rw-r--r--android-project/src/org/libsdl/app/SDLActivity.java9
1 files changed, 5 insertions, 4 deletions
diff --git a/android-project/src/org/libsdl/app/SDLActivity.java b/android-project/src/org/libsdl/app/SDLActivity.java
index 9dd24d2d17..9bdf1e7188 100644
--- a/android-project/src/org/libsdl/app/SDLActivity.java
+++ b/android-project/src/org/libsdl/app/SDLActivity.java
@@ -120,10 +120,11 @@ public class SDLActivity extends Activity {
* This method is called by SDL if SDL did not handle a message itself.
* This happens if a received message contains an unsupported command.
* Method can be overwritten to handle Messages in a different class.
* @param msg the Message which was not handled.
* @return if the Message was handled in method.
*/
- protected boolean onUnhandledMessage(Message msg) {
+ protected boolean onUnhandledMessage(int command, Object param) {
return false;
}
@@ -158,7 +159,7 @@ public class SDLActivity extends Activity {
break;
default:
- if ((context instanceof SDLActivity) && !((SDLActivity) context).onUnhandledMessage(msg)) {
+ if ((context instanceof SDLActivity) && !((SDLActivity) context).onUnhandledMessage(msg.arg1, msg.obj)) {
Log.e(TAG, "error handling message, command is " + msg.arg1);
}
}
@@ -120,10 +120,11 @@ public class SDLActivity extends Activity {
* This happens if a received message contains an unsupported command.
* Method can be overwritten to handle Messages in a different class.
- * @param msg the Message which was not handled.
- * @return if the Message was handled in method.
+ * @param command the command of the message.
+ * @param param the parameter of the message. May be null.
+ * @return if the message was handled in overridden method.
*/